# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: service-mesh-probe/service-mesh.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import Common_pb2 as common_dot_Common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='service-mesh-probe/service-mesh.proto',
  package='skywalking.v3',
  syntax='proto3',
  serialized_options=b'\n0org.apache.skywalking.apm.network.servicemesh.v3P\001Z7skywalking.apache.org/repo/goapi/collect/servicemesh/v3\252\002\035SkyWalking.NetworkProtocol.V3',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%service-mesh-probe/service-mesh.proto\x12\rskywalking.v3\x1a\x13\x63ommon/Common.proto\"\x9d\x03\n\x11ServiceMeshMetric\x12\x11\n\tstartTime\x18\x01 \x01(\x03\x12\x0f\n\x07\x65ndTime\x18\x02 \x01(\x03\x12\x19\n\x11sourceServiceName\x18\x03 \x01(\t\x12\x1d\n\x15sourceServiceInstance\x18\x04 \x01(\t\x12\x17\n\x0f\x64\x65stServiceName\x18\x05 \x01(\t\x12\x1b\n\x13\x64\x65stServiceInstance\x18\x06 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x07 \x01(\t\x12\x0f\n\x07latency\x18\x08 \x01(\x05\x12\x14\n\x0cresponseCode\x18\t \x01(\x05\x12\x0e\n\x06status\x18\n \x01(\x08\x12)\n\x08protocol\x18\x0b \x01(\x0e\x32\x17.skywalking.v3.Protocol\x12/\n\x0b\x64\x65tectPoint\x18\x0c \x01(\x0e\x32\x1a.skywalking.v3.DetectPoint\x12\x0f\n\x07tlsMode\x18\r \x01(\t\x12\x19\n\x11internalErrorCode\x18\x0e \x01(\t\x12#\n\x03tcp\x18\x0f \x01(\x0b\x32\x16.skywalking.v3.TCPInfo\"3\n\x07TCPInfo\x12\x15\n\rreceivedBytes\x18\x01 \x01(\x03\x12\x11\n\tsentBytes\x18\x02 \x01(\x03\"\x15\n\x13MeshProbeDownstream*\'\n\x08Protocol\x12\x08\n\x04HTTP\x10\x00\x12\x08\n\x04gRPC\x10\x01\x12\x07\n\x03TCP\x10\x02\x32o\n\x18ServiceMeshMetricService\x12S\n\x07\x63ollect\x12 .skywalking.v3.ServiceMeshMetric\x1a\".skywalking.v3.MeshProbeDownstream\"\x00(\x01\x42\x8d\x01\n0org.apache.skywalking.apm.network.servicemesh.v3P\x01Z7skywalking.apache.org/repo/goapi/collect/servicemesh/v3\xaa\x02\x1dSkyWalking.NetworkProtocol.V3b\x06proto3'
  ,
  dependencies=[common_dot_Common__pb2.DESCRIPTOR,])

_PROTOCOL = _descriptor.EnumDescriptor(
  name='Protocol',
  full_name='skywalking.v3.Protocol',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HTTP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='gRPC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TCP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=569,
  serialized_end=608,
)
_sym_db.RegisterEnumDescriptor(_PROTOCOL)

Protocol = enum_type_wrapper.EnumTypeWrapper(_PROTOCOL)
HTTP = 0
gRPC = 1
TCP = 2



_SERVICEMESHMETRIC = _descriptor.Descriptor(
  name='ServiceMeshMetric',
  full_name='skywalking.v3.ServiceMeshMetric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='startTime', full_name='skywalking.v3.ServiceMeshMetric.startTime', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='skywalking.v3.ServiceMeshMetric.endTime', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sourceServiceName', full_name='skywalking.v3.ServiceMeshMetric.sourceServiceName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sourceServiceInstance', full_name='skywalking.v3.ServiceMeshMetric.sourceServiceInstance', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destServiceName', full_name='skywalking.v3.ServiceMeshMetric.destServiceName', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destServiceInstance', full_name='skywalking.v3.ServiceMeshMetric.destServiceInstance', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='skywalking.v3.ServiceMeshMetric.endpoint', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency', full_name='skywalking.v3.ServiceMeshMetric.latency', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='responseCode', full_name='skywalking.v3.ServiceMeshMetric.responseCode', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='skywalking.v3.ServiceMeshMetric.status', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='skywalking.v3.ServiceMeshMetric.protocol', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detectPoint', full_name='skywalking.v3.ServiceMeshMetric.detectPoint', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tlsMode', full_name='skywalking.v3.ServiceMeshMetric.tlsMode', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internalErrorCode', full_name='skywalking.v3.ServiceMeshMetric.internalErrorCode', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp', full_name='skywalking.v3.ServiceMeshMetric.tcp', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=491,
)


_TCPINFO = _descriptor.Descriptor(
  name='TCPInfo',
  full_name='skywalking.v3.TCPInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='receivedBytes', full_name='skywalking.v3.TCPInfo.receivedBytes', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sentBytes', full_name='skywalking.v3.TCPInfo.sentBytes', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=544,
)


_MESHPROBEDOWNSTREAM = _descriptor.Descriptor(
  name='MeshProbeDownstream',
  full_name='skywalking.v3.MeshProbeDownstream',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=546,
  serialized_end=567,
)

_SERVICEMESHMETRIC.fields_by_name['protocol'].enum_type = _PROTOCOL
_SERVICEMESHMETRIC.fields_by_name['detectPoint'].enum_type = common_dot_Common__pb2._DETECTPOINT
_SERVICEMESHMETRIC.fields_by_name['tcp'].message_type = _TCPINFO
DESCRIPTOR.message_types_by_name['ServiceMeshMetric'] = _SERVICEMESHMETRIC
DESCRIPTOR.message_types_by_name['TCPInfo'] = _TCPINFO
DESCRIPTOR.message_types_by_name['MeshProbeDownstream'] = _MESHPROBEDOWNSTREAM
DESCRIPTOR.enum_types_by_name['Protocol'] = _PROTOCOL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServiceMeshMetric = _reflection.GeneratedProtocolMessageType('ServiceMeshMetric', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEMESHMETRIC,
  '__module__' : 'service_mesh_probe.service_mesh_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.ServiceMeshMetric)
  })
_sym_db.RegisterMessage(ServiceMeshMetric)

TCPInfo = _reflection.GeneratedProtocolMessageType('TCPInfo', (_message.Message,), {
  'DESCRIPTOR' : _TCPINFO,
  '__module__' : 'service_mesh_probe.service_mesh_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.TCPInfo)
  })
_sym_db.RegisterMessage(TCPInfo)

MeshProbeDownstream = _reflection.GeneratedProtocolMessageType('MeshProbeDownstream', (_message.Message,), {
  'DESCRIPTOR' : _MESHPROBEDOWNSTREAM,
  '__module__' : 'service_mesh_probe.service_mesh_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.MeshProbeDownstream)
  })
_sym_db.RegisterMessage(MeshProbeDownstream)


DESCRIPTOR._options = None

_SERVICEMESHMETRICSERVICE = _descriptor.ServiceDescriptor(
  name='ServiceMeshMetricService',
  full_name='skywalking.v3.ServiceMeshMetricService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=610,
  serialized_end=721,
  methods=[
  _descriptor.MethodDescriptor(
    name='collect',
    full_name='skywalking.v3.ServiceMeshMetricService.collect',
    index=0,
    containing_service=None,
    input_type=_SERVICEMESHMETRIC,
    output_type=_MESHPROBEDOWNSTREAM,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVICEMESHMETRICSERVICE)

DESCRIPTOR.services_by_name['ServiceMeshMetricService'] = _SERVICEMESHMETRICSERVICE

# @@protoc_insertion_point(module_scope)
