# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: logging/Logging.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import Common_pb2 as common_dot_Common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='logging/Logging.proto',
  package='skywalking.v3',
  syntax='proto3',
  serialized_options=b'\n,org.apache.skywalking.apm.network.logging.v3P\001Z3skywalking.apache.org/repo/goapi/collect/logging/v3\252\002\035SkyWalking.NetworkProtocol.V3',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15logging/Logging.proto\x12\rskywalking.v3\x1a\x13\x63ommon/Common.proto\"\xdb\x01\n\x07LogData\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x17\n\x0fserviceInstance\x18\x03 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x04 \x01(\t\x12(\n\x04\x62ody\x18\x05 \x01(\x0b\x32\x1a.skywalking.v3.LogDataBody\x12\x31\n\x0ctraceContext\x18\x06 \x01(\x0b\x32\x1b.skywalking.v3.TraceContext\x12$\n\x04tags\x18\x07 \x01(\x0b\x32\x16.skywalking.v3.LogTags\"\x9e\x01\n\x0bLogDataBody\x12\x0c\n\x04type\x18\x01 \x01(\t\x12&\n\x04text\x18\x02 \x01(\x0b\x32\x16.skywalking.v3.TextLogH\x00\x12&\n\x04json\x18\x03 \x01(\x0b\x32\x16.skywalking.v3.JSONLogH\x00\x12&\n\x04yaml\x18\x04 \x01(\x0b\x32\x16.skywalking.v3.YAMLLogH\x00\x42\t\n\x07\x63ontent\"\x17\n\x07TextLog\x12\x0c\n\x04text\x18\x01 \x01(\t\"\x17\n\x07JSONLog\x12\x0c\n\x04json\x18\x01 \x01(\t\"\x17\n\x07YAMLLog\x12\x0c\n\x04yaml\x18\x01 \x01(\t\"G\n\x0cTraceContext\x12\x0f\n\x07traceId\x18\x01 \x01(\t\x12\x16\n\x0etraceSegmentId\x18\x02 \x01(\t\x12\x0e\n\x06spanId\x18\x03 \x01(\x05\":\n\x07LogTags\x12/\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32!.skywalking.v3.KeyStringValuePair2R\n\x10LogReportService\x12>\n\x07\x63ollect\x12\x16.skywalking.v3.LogData\x1a\x17.skywalking.v3.Commands\"\x00(\x01\x42\x85\x01\n,org.apache.skywalking.apm.network.logging.v3P\x01Z3skywalking.apache.org/repo/goapi/collect/logging/v3\xaa\x02\x1dSkyWalking.NetworkProtocol.V3b\x06proto3'
  ,
  dependencies=[common_dot_Common__pb2.DESCRIPTOR,])




_LOGDATA = _descriptor.Descriptor(
  name='LogData',
  full_name='skywalking.v3.LogData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='skywalking.v3.LogData.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='skywalking.v3.LogData.service', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serviceInstance', full_name='skywalking.v3.LogData.serviceInstance', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='skywalking.v3.LogData.endpoint', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='skywalking.v3.LogData.body', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traceContext', full_name='skywalking.v3.LogData.traceContext', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='skywalking.v3.LogData.tags', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=281,
)


_LOGDATABODY = _descriptor.Descriptor(
  name='LogDataBody',
  full_name='skywalking.v3.LogDataBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='skywalking.v3.LogDataBody.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='skywalking.v3.LogDataBody.text', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json', full_name='skywalking.v3.LogDataBody.json', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='skywalking.v3.LogDataBody.yaml', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='skywalking.v3.LogDataBody.content',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=284,
  serialized_end=442,
)


_TEXTLOG = _descriptor.Descriptor(
  name='TextLog',
  full_name='skywalking.v3.TextLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='skywalking.v3.TextLog.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=467,
)


_JSONLOG = _descriptor.Descriptor(
  name='JSONLog',
  full_name='skywalking.v3.JSONLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='json', full_name='skywalking.v3.JSONLog.json', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=492,
)


_YAMLLOG = _descriptor.Descriptor(
  name='YAMLLog',
  full_name='skywalking.v3.YAMLLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='yaml', full_name='skywalking.v3.YAMLLog.yaml', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=517,
)


_TRACECONTEXT = _descriptor.Descriptor(
  name='TraceContext',
  full_name='skywalking.v3.TraceContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='traceId', full_name='skywalking.v3.TraceContext.traceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traceSegmentId', full_name='skywalking.v3.TraceContext.traceSegmentId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spanId', full_name='skywalking.v3.TraceContext.spanId', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=590,
)


_LOGTAGS = _descriptor.Descriptor(
  name='LogTags',
  full_name='skywalking.v3.LogTags',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='skywalking.v3.LogTags.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=650,
)

_LOGDATA.fields_by_name['body'].message_type = _LOGDATABODY
_LOGDATA.fields_by_name['traceContext'].message_type = _TRACECONTEXT
_LOGDATA.fields_by_name['tags'].message_type = _LOGTAGS
_LOGDATABODY.fields_by_name['text'].message_type = _TEXTLOG
_LOGDATABODY.fields_by_name['json'].message_type = _JSONLOG
_LOGDATABODY.fields_by_name['yaml'].message_type = _YAMLLOG
_LOGDATABODY.oneofs_by_name['content'].fields.append(
  _LOGDATABODY.fields_by_name['text'])
_LOGDATABODY.fields_by_name['text'].containing_oneof = _LOGDATABODY.oneofs_by_name['content']
_LOGDATABODY.oneofs_by_name['content'].fields.append(
  _LOGDATABODY.fields_by_name['json'])
_LOGDATABODY.fields_by_name['json'].containing_oneof = _LOGDATABODY.oneofs_by_name['content']
_LOGDATABODY.oneofs_by_name['content'].fields.append(
  _LOGDATABODY.fields_by_name['yaml'])
_LOGDATABODY.fields_by_name['yaml'].containing_oneof = _LOGDATABODY.oneofs_by_name['content']
_LOGTAGS.fields_by_name['data'].message_type = common_dot_Common__pb2._KEYSTRINGVALUEPAIR
DESCRIPTOR.message_types_by_name['LogData'] = _LOGDATA
DESCRIPTOR.message_types_by_name['LogDataBody'] = _LOGDATABODY
DESCRIPTOR.message_types_by_name['TextLog'] = _TEXTLOG
DESCRIPTOR.message_types_by_name['JSONLog'] = _JSONLOG
DESCRIPTOR.message_types_by_name['YAMLLog'] = _YAMLLOG
DESCRIPTOR.message_types_by_name['TraceContext'] = _TRACECONTEXT
DESCRIPTOR.message_types_by_name['LogTags'] = _LOGTAGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LogData = _reflection.GeneratedProtocolMessageType('LogData', (_message.Message,), {
  'DESCRIPTOR' : _LOGDATA,
  '__module__' : 'logging.Logging_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.LogData)
  })
_sym_db.RegisterMessage(LogData)

LogDataBody = _reflection.GeneratedProtocolMessageType('LogDataBody', (_message.Message,), {
  'DESCRIPTOR' : _LOGDATABODY,
  '__module__' : 'logging.Logging_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.LogDataBody)
  })
_sym_db.RegisterMessage(LogDataBody)

TextLog = _reflection.GeneratedProtocolMessageType('TextLog', (_message.Message,), {
  'DESCRIPTOR' : _TEXTLOG,
  '__module__' : 'logging.Logging_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.TextLog)
  })
_sym_db.RegisterMessage(TextLog)

JSONLog = _reflection.GeneratedProtocolMessageType('JSONLog', (_message.Message,), {
  'DESCRIPTOR' : _JSONLOG,
  '__module__' : 'logging.Logging_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.JSONLog)
  })
_sym_db.RegisterMessage(JSONLog)

YAMLLog = _reflection.GeneratedProtocolMessageType('YAMLLog', (_message.Message,), {
  'DESCRIPTOR' : _YAMLLOG,
  '__module__' : 'logging.Logging_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.YAMLLog)
  })
_sym_db.RegisterMessage(YAMLLog)

TraceContext = _reflection.GeneratedProtocolMessageType('TraceContext', (_message.Message,), {
  'DESCRIPTOR' : _TRACECONTEXT,
  '__module__' : 'logging.Logging_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.TraceContext)
  })
_sym_db.RegisterMessage(TraceContext)

LogTags = _reflection.GeneratedProtocolMessageType('LogTags', (_message.Message,), {
  'DESCRIPTOR' : _LOGTAGS,
  '__module__' : 'logging.Logging_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.LogTags)
  })
_sym_db.RegisterMessage(LogTags)


DESCRIPTOR._options = None

_LOGREPORTSERVICE = _descriptor.ServiceDescriptor(
  name='LogReportService',
  full_name='skywalking.v3.LogReportService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=652,
  serialized_end=734,
  methods=[
  _descriptor.MethodDescriptor(
    name='collect',
    full_name='skywalking.v3.LogReportService.collect',
    index=0,
    containing_service=None,
    input_type=_LOGDATA,
    output_type=common_dot_Common__pb2._COMMANDS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOGREPORTSERVICE)

DESCRIPTOR.services_by_name['LogReportService'] = _LOGREPORTSERVICE

# @@protoc_insertion_point(module_scope)
