# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: profile/Profile.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import Common_pb2 as common_dot_Common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='profile/Profile.proto',
  package='skywalking.v3',
  syntax='proto3',
  serialized_options=b'\n5org.apache.skywalking.apm.network.language.profile.v3P\001Z<skywalking.apache.org/repo/goapi/collect/language/profile/v3\252\002\035SkyWalking.NetworkProtocol.V3',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15profile/Profile.proto\x12\rskywalking.v3\x1a\x13\x63ommon/Common.proto\"\\\n\x17ProfileTaskCommandQuery\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x17\n\x0fserviceInstance\x18\x02 \x01(\t\x12\x17\n\x0flastCommandTime\x18\x03 \x01(\x03\"\x83\x01\n\x0eThreadSnapshot\x12\x0e\n\x06taskId\x18\x01 \x01(\t\x12\x16\n\x0etraceSegmentId\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\x03\x12\x10\n\x08sequence\x18\x04 \x01(\x05\x12)\n\x05stack\x18\x05 \x01(\x0b\x32\x1a.skywalking.v3.ThreadStack\"%\n\x0bThreadStack\x12\x16\n\x0e\x63odeSignatures\x18\x01 \x03(\t\"S\n\x17ProfileTaskFinishReport\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x17\n\x0fserviceInstance\x18\x02 \x01(\t\x12\x0e\n\x06taskId\x18\x03 \x01(\t2\x90\x02\n\x0bProfileTask\x12[\n\x16getProfileTaskCommands\x12&.skywalking.v3.ProfileTaskCommandQuery\x1a\x17.skywalking.v3.Commands\"\x00\x12M\n\x0f\x63ollectSnapshot\x12\x1d.skywalking.v3.ThreadSnapshot\x1a\x17.skywalking.v3.Commands\"\x00(\x01\x12U\n\x10reportTaskFinish\x12&.skywalking.v3.ProfileTaskFinishReport\x1a\x17.skywalking.v3.Commands\"\x00\x42\x97\x01\n5org.apache.skywalking.apm.network.language.profile.v3P\x01Z<skywalking.apache.org/repo/goapi/collect/language/profile/v3\xaa\x02\x1dSkyWalking.NetworkProtocol.V3b\x06proto3'
  ,
  dependencies=[common_dot_Common__pb2.DESCRIPTOR,])




_PROFILETASKCOMMANDQUERY = _descriptor.Descriptor(
  name='ProfileTaskCommandQuery',
  full_name='skywalking.v3.ProfileTaskCommandQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='skywalking.v3.ProfileTaskCommandQuery.service', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serviceInstance', full_name='skywalking.v3.ProfileTaskCommandQuery.serviceInstance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastCommandTime', full_name='skywalking.v3.ProfileTaskCommandQuery.lastCommandTime', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=153,
)


_THREADSNAPSHOT = _descriptor.Descriptor(
  name='ThreadSnapshot',
  full_name='skywalking.v3.ThreadSnapshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='taskId', full_name='skywalking.v3.ThreadSnapshot.taskId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traceSegmentId', full_name='skywalking.v3.ThreadSnapshot.traceSegmentId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='skywalking.v3.ThreadSnapshot.time', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='skywalking.v3.ThreadSnapshot.sequence', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stack', full_name='skywalking.v3.ThreadSnapshot.stack', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=287,
)


_THREADSTACK = _descriptor.Descriptor(
  name='ThreadStack',
  full_name='skywalking.v3.ThreadStack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='codeSignatures', full_name='skywalking.v3.ThreadStack.codeSignatures', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=289,
  serialized_end=326,
)


_PROFILETASKFINISHREPORT = _descriptor.Descriptor(
  name='ProfileTaskFinishReport',
  full_name='skywalking.v3.ProfileTaskFinishReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='skywalking.v3.ProfileTaskFinishReport.service', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serviceInstance', full_name='skywalking.v3.ProfileTaskFinishReport.serviceInstance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taskId', full_name='skywalking.v3.ProfileTaskFinishReport.taskId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=411,
)

_THREADSNAPSHOT.fields_by_name['stack'].message_type = _THREADSTACK
DESCRIPTOR.message_types_by_name['ProfileTaskCommandQuery'] = _PROFILETASKCOMMANDQUERY
DESCRIPTOR.message_types_by_name['ThreadSnapshot'] = _THREADSNAPSHOT
DESCRIPTOR.message_types_by_name['ThreadStack'] = _THREADSTACK
DESCRIPTOR.message_types_by_name['ProfileTaskFinishReport'] = _PROFILETASKFINISHREPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProfileTaskCommandQuery = _reflection.GeneratedProtocolMessageType('ProfileTaskCommandQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROFILETASKCOMMANDQUERY,
  '__module__' : 'profile.Profile_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.ProfileTaskCommandQuery)
  })
_sym_db.RegisterMessage(ProfileTaskCommandQuery)

ThreadSnapshot = _reflection.GeneratedProtocolMessageType('ThreadSnapshot', (_message.Message,), {
  'DESCRIPTOR' : _THREADSNAPSHOT,
  '__module__' : 'profile.Profile_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.ThreadSnapshot)
  })
_sym_db.RegisterMessage(ThreadSnapshot)

ThreadStack = _reflection.GeneratedProtocolMessageType('ThreadStack', (_message.Message,), {
  'DESCRIPTOR' : _THREADSTACK,
  '__module__' : 'profile.Profile_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.ThreadStack)
  })
_sym_db.RegisterMessage(ThreadStack)

ProfileTaskFinishReport = _reflection.GeneratedProtocolMessageType('ProfileTaskFinishReport', (_message.Message,), {
  'DESCRIPTOR' : _PROFILETASKFINISHREPORT,
  '__module__' : 'profile.Profile_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.ProfileTaskFinishReport)
  })
_sym_db.RegisterMessage(ProfileTaskFinishReport)


DESCRIPTOR._options = None

_PROFILETASK = _descriptor.ServiceDescriptor(
  name='ProfileTask',
  full_name='skywalking.v3.ProfileTask',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=414,
  serialized_end=686,
  methods=[
  _descriptor.MethodDescriptor(
    name='getProfileTaskCommands',
    full_name='skywalking.v3.ProfileTask.getProfileTaskCommands',
    index=0,
    containing_service=None,
    input_type=_PROFILETASKCOMMANDQUERY,
    output_type=common_dot_Common__pb2._COMMANDS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='collectSnapshot',
    full_name='skywalking.v3.ProfileTask.collectSnapshot',
    index=1,
    containing_service=None,
    input_type=_THREADSNAPSHOT,
    output_type=common_dot_Common__pb2._COMMANDS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='reportTaskFinish',
    full_name='skywalking.v3.ProfileTask.reportTaskFinish',
    index=2,
    containing_service=None,
    input_type=_PROFILETASKFINISHREPORT,
    output_type=common_dot_Common__pb2._COMMANDS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROFILETASK)

DESCRIPTOR.services_by_name['ProfileTask'] = _PROFILETASK

# @@protoc_insertion_point(module_scope)
