# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: management/Management.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import Common_pb2 as common_dot_Common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='management/Management.proto',
  package='skywalking.v3',
  syntax='proto3',
  serialized_options=b'\n/org.apache.skywalking.apm.network.management.v3P\001Z6skywalking.apache.org/repo/goapi/collect/management/v3\252\002\035SkyWalking.NetworkProtocol.V3',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bmanagement/Management.proto\x12\rskywalking.v3\x1a\x13\x63ommon/Common.proto\"u\n\x12InstanceProperties\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x17\n\x0fserviceInstance\x18\x02 \x01(\t\x12\x35\n\nproperties\x18\x03 \x03(\x0b\x32!.skywalking.v3.KeyStringValuePair\";\n\x0fInstancePingPkg\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x17\n\x0fserviceInstance\x18\x02 \x01(\t2\xb5\x01\n\x11ManagementService\x12X\n\x18reportInstanceProperties\x12!.skywalking.v3.InstanceProperties\x1a\x17.skywalking.v3.Commands\"\x00\x12\x46\n\tkeepAlive\x12\x1e.skywalking.v3.InstancePingPkg\x1a\x17.skywalking.v3.Commands\"\x00\x42\x8b\x01\n/org.apache.skywalking.apm.network.management.v3P\x01Z6skywalking.apache.org/repo/goapi/collect/management/v3\xaa\x02\x1dSkyWalking.NetworkProtocol.V3b\x06proto3'
  ,
  dependencies=[common_dot_Common__pb2.DESCRIPTOR,])




_INSTANCEPROPERTIES = _descriptor.Descriptor(
  name='InstanceProperties',
  full_name='skywalking.v3.InstanceProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='skywalking.v3.InstanceProperties.service', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serviceInstance', full_name='skywalking.v3.InstanceProperties.serviceInstance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='skywalking.v3.InstanceProperties.properties', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=184,
)


_INSTANCEPINGPKG = _descriptor.Descriptor(
  name='InstancePingPkg',
  full_name='skywalking.v3.InstancePingPkg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='skywalking.v3.InstancePingPkg.service', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serviceInstance', full_name='skywalking.v3.InstancePingPkg.serviceInstance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=245,
)

_INSTANCEPROPERTIES.fields_by_name['properties'].message_type = common_dot_Common__pb2._KEYSTRINGVALUEPAIR
DESCRIPTOR.message_types_by_name['InstanceProperties'] = _INSTANCEPROPERTIES
DESCRIPTOR.message_types_by_name['InstancePingPkg'] = _INSTANCEPINGPKG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InstanceProperties = _reflection.GeneratedProtocolMessageType('InstanceProperties', (_message.Message,), {
  'DESCRIPTOR' : _INSTANCEPROPERTIES,
  '__module__' : 'management.Management_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.InstanceProperties)
  })
_sym_db.RegisterMessage(InstanceProperties)

InstancePingPkg = _reflection.GeneratedProtocolMessageType('InstancePingPkg', (_message.Message,), {
  'DESCRIPTOR' : _INSTANCEPINGPKG,
  '__module__' : 'management.Management_pb2'
  # @@protoc_insertion_point(class_scope:skywalking.v3.InstancePingPkg)
  })
_sym_db.RegisterMessage(InstancePingPkg)


DESCRIPTOR._options = None

_MANAGEMENTSERVICE = _descriptor.ServiceDescriptor(
  name='ManagementService',
  full_name='skywalking.v3.ManagementService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=248,
  serialized_end=429,
  methods=[
  _descriptor.MethodDescriptor(
    name='reportInstanceProperties',
    full_name='skywalking.v3.ManagementService.reportInstanceProperties',
    index=0,
    containing_service=None,
    input_type=_INSTANCEPROPERTIES,
    output_type=common_dot_Common__pb2._COMMANDS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='keepAlive',
    full_name='skywalking.v3.ManagementService.keepAlive',
    index=1,
    containing_service=None,
    input_type=_INSTANCEPINGPKG,
    output_type=common_dot_Common__pb2._COMMANDS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MANAGEMENTSERVICE)

DESCRIPTOR.services_by_name['ManagementService'] = _MANAGEMENTSERVICE

# @@protoc_insertion_point(module_scope)
