# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: browser/BrowserPerfCompat.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import Common_pb2 as common_dot_Common__pb2
from ..browser import BrowserPerf_pb2 as browser_dot_BrowserPerf__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='browser/BrowserPerfCompat.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n:org.apache.skywalking.apm.network.language.agent.v3.compatP\001Z:skywalking.apache.org/repo/goapi/collect/language/agent/v3\270\001\001\252\002\035SkyWalking.NetworkProtocol.V3',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x62rowser/BrowserPerfCompat.proto\x1a\x13\x63ommon/Common.proto\x1a\x19\x62rowser/BrowserPerf.proto2\xb3\x01\n\x12\x42rowserPerfService\x12L\n\x0f\x63ollectPerfData\x12\x1e.skywalking.v3.BrowserPerfData\x1a\x17.skywalking.v3.Commands\"\x00\x12O\n\x10\x63ollectErrorLogs\x12\x1e.skywalking.v3.BrowserErrorLog\x1a\x17.skywalking.v3.Commands\"\x00(\x01\x42\x9d\x01\n:org.apache.skywalking.apm.network.language.agent.v3.compatP\x01Z:skywalking.apache.org/repo/goapi/collect/language/agent/v3\xb8\x01\x01\xaa\x02\x1dSkyWalking.NetworkProtocol.V3b\x06proto3'
  ,
  dependencies=[common_dot_Common__pb2.DESCRIPTOR,browser_dot_BrowserPerf__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_BROWSERPERFSERVICE = _descriptor.ServiceDescriptor(
  name='BrowserPerfService',
  full_name='BrowserPerfService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=84,
  serialized_end=263,
  methods=[
  _descriptor.MethodDescriptor(
    name='collectPerfData',
    full_name='BrowserPerfService.collectPerfData',
    index=0,
    containing_service=None,
    input_type=browser_dot_BrowserPerf__pb2._BROWSERPERFDATA,
    output_type=common_dot_Common__pb2._COMMANDS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='collectErrorLogs',
    full_name='BrowserPerfService.collectErrorLogs',
    index=1,
    containing_service=None,
    input_type=browser_dot_BrowserPerf__pb2._BROWSERERRORLOG,
    output_type=common_dot_Common__pb2._COMMANDS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BROWSERPERFSERVICE)

DESCRIPTOR.services_by_name['BrowserPerfService'] = _BROWSERPERFSERVICE

# @@protoc_insertion_point(module_scope)
